@@ -27,7 +27,7 @@ object_name = os
 __package__ = os.path.basename(os.path.dirname(__file__))
 __author__ = "Dillon"
 __email__ = "aa269440877@outlook.com"
-__version__ = "1.0.10"
+__version__ = "1.0.11"
 __url__ = "https://gitee.com/ld269440877/tools/blob/master/my_modules/dir_objectName.py"
 __license__ = "MIT Licence"
 
@@ -487,7 +487,7 @@ def aprint(sequence_or_mapping, columns=4, width=30, pattern=r"^[^_]"):
 
 def modules_from_package(package_name, pattern=r"^[^_]"):
     modules = list()
-    if not all(hasattr(package_name, "__name__"), hasattr(package_name, "__path__")):
+    if not all([hasattr(package_name, "__name__"), hasattr(package_name, "__path__")]):
         return modules
     package_folder = getattr(package_name, '__path__')[0]
     package_name = package_name.__name__
